.. testsetup:: *

   from pwn import *
   import tempfile

:mod:`pwnlib.rop.ret2dlresolve` --- Return to dl_resolve
========================================================

.. automodule:: pwnlib.rop.ret2dlresolve
   :members:
